Cosiest Noisiest
cosiest_noisiest allows generating 1d noise at arbitrary points
Examples
use cosiest_noisiest::*;
let mut noise_generator = NoiseGenerator::from_u64_seed(2, (1./32.).into(), 128., 3);
let noise:f64 = noise_generator.sample(1024);use cosiest_noisiest::*;
let mut noise_generator = NoiseGenerator::from_u64_seed(2, Frequency::from_wave_length(32), 128., 3);
let mut noise= [0.0;1024];
noise_generator.fill(0,&mut noise);Crate Features
f32 - Enables using f32 when interpolating between noise values instead of the default f64.
Structs
- ChaCha20
Rng - A cryptographically secure random number generator that uses the ChaCha algorithm.
- Frequency
- A wrapper struct to ease conversion between freqency and wave_length
- Noise
Generator - A 1D Noise Generator that allows sampling at arbitrary points.
Traits
- Rng
- An automatically-implemented extension trait on
RngCoreproviding high-level generic methods for sampling values and other convenience methods. - Seedable
Rng - A random number generator that can be explicitly seeded.
- Word
Aligned - Marks that a type size is aligned with a word boundary (32 bits as used by ChaCha)